Package: dragulaR
Type: Package
Title: Drag and Drop Elements in 'Shiny' using 'Dragula Javascript
        Library'
Version: 0.3.1
Authors@R: c(person("Nicolas", "Bevacqua", role = c("aut", "cph"),
       comment = "dragula library in htmlwidgets/lib, https://github.com/bevacqua/dragula"),
       person("Zygmunt", "Zawadzki", role = c("aut", "cre"),
       comment = "R interface", email = "zygmunt@zstat.pl"))
Maintainer: Zygmunt Zawadzki <zygmunt@zstat.pl>
Description: Move elements between containers in 'Shiny' without explicitly using 'JavaScript'. It can be used to build custom inputs or to change the positions of user interface elements like plots or tables.
License: GPL-2
LazyData: TRUE
Depends: htmlwidgets, shiny
Imports: shinyjs
RoxygenNote: 6.0.1
Suggests: covr, testthat
BugReports: https://github.com/zzawadz/dragulaR/issues
URL: https://dragular.zstat.pl/
NeedsCompilation: no
Packaged: 2018-06-15 18:16:18 UTC; zzawadz
Author: Nicolas Bevacqua [aut, cph] (dragula library in htmlwidgets/lib,
    https://github.com/bevacqua/dragula),
  Zygmunt Zawadzki [aut, cre] (R interface)
Repository: CRAN
Date/Publication: 2018-06-17 14:08:01 UTC
Built: R 4.6.0; ; 2026-04-26 17:43:31 UTC; unix
